============
Installation
============

At the command line::

    $ pip install reno

Sphinx Extension
================

To use the Sphinx extension built into reno, install the ``[sphinx]``
extra dependencies::

    $ pip install 'reno[sphinx]'
